\LoadClass[twocolumn,twoside,10pt]{article}
\RequirePackage{amsmath,amsthm,amsfonts,amssymb,bm,upgreek,multicol,mathrsfs,pifont,amscd,latexsym,geometry,color,fancyhdr}
\geometry{paperwidth=216mm,paperheight=285mm}


\RequirePackage{graphicx,picins}
\RequirePackage{algorithm,algorithmic,tabularx,float,booktabs,multirow,colortbl}
\RequirePackage{ifpdf}
\RequirePackage{fancyhdr}
\RequirePackage{epstopdf}

\usepackage{flushend,cuted}
\usepackage{abstract}


\RequirePackage{overpic}
\RequirePackage[english]{babel}

\usepackage{times}
\usepackage{mathptmx}
\usepackage{indentfirst}

\usepackage[nospace,nobreak,noadjust]{cite}
\def\citedash{-}
\newcommand{\upcite}[1]{$^{\mbox{\scriptsize \cite{#1}}}$}


%%%%%%%%%%%%%% layout %%%%%%%%%%%%%%%%%%%

\textwidth=180truemm
\textheight=233truemm
\topmargin=-24.7truemm
\headsep=15truemm
\headheight=14.5truemm
\oddsidemargin=-15pt
\evensidemargin=-28pt
\parindent=10.8pt
\columnsep .7cm

\renewcommand{\baselinestretch}{1.0669}
\renewcommand{\arraystretch}{1.2}
\newcommand{\shibapt}{\fontsize{18pt}{2\baselineskip}\selectfont}
\newcommand{\shipt}{\fontsize{10pt}{\baselineskip}\selectfont}
\newcommand{\bapt}{\fontsize{8pt}{\baselineskip}\selectfont}
\newcommand{\qipt}{\fontsize{7pt}{0.8\baselineskip}\selectfont}




%%%%%%%%%%%%%%%% Article  %%%%%%%%%%%%%%%%%%%%%%%

\def\@journal{Journal of Communications and Information Networks}

\let\@ArticleType\@empty \def\ArticleType#1{\def\@ArticleType{#1}}
\let\@Year\@empty \def\Year#1{\def\@Year{#1}}
\let\@abstract\@empty \renewcommand\abstract[1]{\def\@abstract{#1}}
\let\@keywords\@empty \def\keywords#1{\def\@keywords{#1}}
\let\@Acknowl\@empty \def\Acknowl#1{\def\@Acknowl{#1}}


%%%%%%%%%%%%%%%  maketitle  %%%%%%%%%%%%%%%%%%%%

\let\@title\@empty
\renewcommand\title[3][]{
  \def\@title{#2}
  \def\@titlecitation{#3}
  \ifx\@titlecitation\@empty\def\@titlecitation{#2}\fi
}


\let\@author\@empty
\let\@authorcite\@empty
\renewcommand*{\author}[2][]{%
  \ifx\@author\@empty
    \def\@author{#2\@authornote{#1}}
    \let\@authortemp\@author
  \else
    \let\@author\@authortemp
    \expandafter\def\expandafter\@author\expandafter
      {\@author{,}~#2\@authornote{#1}}
    \expandafter\def\expandafter\@authortemp\expandafter
      {\@authortemp,~#2\@authornote{#1}}
  \fi

  \ifx\@AuthorCitation\@empty
    \ifx\@authorcite\@empty \def\@authorcite{#2}
    \else \expandafter\def\expandafter\@authorcite\expandafter{\@authorcite, #2}
    \fi
  \fi
}


\def\@authornote#1{%
  \def\JCIN@author@address{#1}%
  \ifx\JCIN@author@address\@empty
  \else \textsuperscript{#1}\hspace{-1.2mm}
  \fi
}


\def\@address{}
\newcommand*{\address}[2][]{%
  \ifx \@address\@empty
    \def\@address{\@addressline{#1}{#2}}
  \else
    \expandafter\def\expandafter\@address\expandafter
      {\@address\tabularnewline\@addressline{#1}{#2}}
  \fi}
\def\@addressline#1#2{\@addresscr\hb@xt@2.5ex{{\rm#1}.~\hss}#2}
\def\@addresscr{\def\\{\tabularnewline\@addresscr\hbox to2.5ex{}\ignorespaces}}



\renewcommand\maketitle{\par
  \begingroup
    \renewcommand\thefootnote{\fnsymbol{footnote}}
    \long\def\@makefntext##1{\baselineskip 11pt\noindent{\normalfont\@thefnmark}##1}
    \@maketitle
    \thispagestyle{empty}\@thanks
  \endgroup
  \setcounter{page}{1}
  \renewcommand{\baselinestretch}{1.21}
  \baselineskip 12pt
  \parindent=10.8pt
  \shipt
  \vspace{5mm}
}


\def\@maketitle{
    \renewcommand{\baselinestretch}{0.9}
    \baselineskip 9pt
    \vspace*{52.22mm}
    \begin{picture}(0,0)
            \rm
            \put(0,180){\qipt\@journal}
            \put(387,180){\makebox[45truemm][r]{\bf\Large~\@ArticleType~}}
    \end{picture}
    \noindent
    \vskip -40mm
    {\renewcommand{\baselinestretch}{1.1}%
    \Huge{\parbox{\textwidth}{\centering \@title}}}

    \vskip 0.5 true cm
    \renewcommand{\baselinestretch}{1.1}
    \baselineskip 12pt
    \hskip 0.8 true cm
    \begin{center}\shipt{\rm
        \begin{tabular}[t]{@{}l@{}}
          \@author
        \end{tabular}
    }

%    \vskip  .5 true cm
    \hskip  .8 true cm
    \baselineskip 9pt
%    {\renewcommand{\baselinestretch}{1.1}\bapt{\rm
%        \begin{tabular}[t]{@{}l@{}}
%           \@address
%        \end{tabular}}
%    }
    \end{center}

%    \vskip  .3 true cm
%    \begin{center}
%    \begin{minipage}{\columnwidth}
%    \bapt\noindent\textbf{Abstract:}\quad\ignorespaces\@abstract\newline%
%    \vskip -2 true mm%
%    \noindent\bapt\noindent\textbf{Keywords:}\quad\ignorespaces\@keywords
%    \end{minipage}
%    \end{center}

%    \vskip  .3 true cm
%    {\scriptsize\@Acknowl}
}

\newcommand\barefootnote[1]{\begingroup%
\renewcommand\thefootnote{}\footnote{#1}%
\addtocounter{footnote}{-1}%
\endgroup}

%%%%%%%%%%%%%%% myheadings %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\def\ps@myheadings{\global\let\@oddfoot\@empty\global\let\@evenfoot\@empty
    \def\@evenhead{\vbox{
    \vspace*{-4.6mm}
    \makebox[-3.9mm][l]{\thepage}%
    \hskip 3.6mm
    \makebox[\textwidth][c]{{\textsl{\@journal}}}
    \rule[-2mm]{\textwidth}{0.3mm}
    }}

    \def\@oddhead{\vbox{
    \vspace*{-4.6mm}%
    \makebox[-2mm][r]{}\hspace*{1.6mm}\makebox[\textwidth][c]{{\textsl{\@title}}}%
    \makebox[-4mm][l]{}%
    \makebox[4.7mm][r]{\thepage}
    \rule[-2mm]{\textwidth}{0.3mm}
    }}
}
\pagestyle{myheadings}



%%%%%%%%%%%%% Figures and tables %%%%%%%%%%%%%%%%%%%%

\setlength{\floatsep}{12pt plus 2pt minus 2pt}%Ò³Ãæ¶¥²¿/µ×²¿µÄ¸¡¶¯¶ÔÏó¼äµÄ´¹Ö±¾àÀë, È±Ê¡Îª12pt plus 2pt minus 2pt
\setlength{\textfloatsep}{12pt plus 2pt minus 2pt}%Ò³¶¥²¿/µ×²¿µÄ¸¡¶¯¶ÔÏóÓëÎÄ±¾¼ä´¹Ö±¾àÀë, È±Ê¡20pt plus 2pt minus 4pt
\setlength{\intextsep}{12pt plus 2pt minus 2pt}%Ò³ÖÐ¸¡¶¯¶ÔÏóÓëÉÏÏÂ·½ÎÄ±¾¼ä´¹Ö±¾àÀë, È±Ê¡12pt plus 2pt minus 2pt
\setlength{\belowrulesep}{0pt}%ºáÏßºÍÆäÏÂÎÄ×ÖµÄ¼ä¾à
\setlength{\aboverulesep}{0pt}%ºáÏßºÍÆäÉÏÎÄ×ÖµÄ¼ä¾à
\setlength{\doublerulesep}{0.4pt}
%\newcommand\Times{\fontfamily{ptm}\selectfont}
\newcommand{\picsize}{\fontsize{7.5pt}{0.4\baselineskip}\selectfont}
\usepackage[bf,footnotesize,labelsep=quad]{caption}
\usepackage[labelfont={rm,md,up}]{subfig}
\captionsetup[subfloat]{labelformat=simple,captionskip=2pt}
\captionsetup[table]{aboveskip=1mm}
\captionsetup[figure]{aboveskip=3mm}
\captionsetup[algorithm]{font=footnotesize}
\renewcommand{\thesubfigure}{{(\alph{subfigure})}} %ÕâÁ½ÐÐ¶¨Òå×ÓÍ¼ÔÚÕýÎÄÒýÓÃÊ±µÄlabelÐÎÊ½
\renewcommand{\thesubtable}{{\footnotesize(\alph{subtable})}} %×Ó±ílabelµÄ×ÖÌåÈÔºÍÕýÎÄÏàÍ¬




%%%%%%%%%%%%%%%%%%%% Math %%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%% Theorems %%%%%%%%%%%%%%%%%%%

\def\proof{\noindent\textbf{Proof}\quad}
\def\th#1{\noindent{\bf #1}\quad}
\renewcommand{\qedsymbol}{}
\newtheoremstyle{newdefinition}%
    {2pt}
    {2pt}
    {\normalfont}
    {}
    {\bfseries}
    {}
    {10pt plus 1pt minus 1pt}
    {}
\theoremstyle{newdefinition}
\newtheorem{definition}{Definition}
\newtheorem{theorem}{Theorem}
\newtheorem{proposition}{Proposition}
\newtheorem{lemma}{Lemma}
\newtheorem{corollary}{Corollary}
\newtheorem{assumption}{Assumption}
\newtheorem{problem}{Problem}
\newtheorem{remark}{Remark}
\newtheorem{example}{Example}



%%%%%%%%%%%%%%%  list  %%%%%%%%%%%%%%%%%%%
\renewenvironment{itemize}{
\begin{list}{$\bullet$}{
\labelwidth=4em
\labelsep=0.5em
\leftmargin=0em
\rightmargin=0em
\parsep=\parskip
\itemsep=0em
\topsep=0em
\itemindent=2.1em
}
}{\end{list}}



\let\oldmaketitle\maketitle
\renewcommand*{\maketitle}{%
\twocolumn[
\begin{@twocolumnfalse}
\oldmaketitle
\vspace{5mm}
\end{@twocolumnfalse}
]
}


\endinput
